@@ -31,8 +31,16 @@ from .common import (
 )
 
 if t.TYPE_CHECKING:
+    import sys
+    import types
+
     from libtmux.common import tmux_cmd
 
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
     from .server import Server
 
 
@@ -63,6 +71,13 @@ class Session(Obj, EnvironmentMixin):
     >>> session.active_pane
     Pane(%1 Window(@1 ...:..., Session($1 ...)))
 
+    The session can be used as a context manager to ensure proper cleanup:
+
+    >>> with server.new_session() as session:
+    ...     window = session.new_window()
+    ...     # Do work with the window
+    ...     # Session will be killed automatically when exiting the context
+
     References
     ----------
     .. [session_manual] tmux session. openbsd manpage for TMUX(1).
@@ -78,6 +93,36 @@ class Session(Obj, EnvironmentMixin):
 
     server: Server
 
+    def __enter__(self) -> Self:
+        """Enter the context, returning self.
+
+        Returns
+        -------
+        :class:`Session`
+            The session instance
+        """
+        return self
+
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: types.TracebackType | None,
+    ) -> None:
+        """Exit the context, killing the session if it exists.
+
+        Parameters
+        ----------
+        exc_type : type[BaseException] | None
+            The type of the exception that was raised
+        exc_value : BaseException | None
+            The instance of the exception that was raised
+        exc_tb : types.TracebackType | None
+            The traceback of the exception that was raised
+        """
+        if self.session_name is not None and self.server.has_session(self.session_name):
+            self.kill()
+
     def refresh(self) -> None:
         """Refresh session attributes from tmux."""
         assert isinstance(self.session_id, str)
